@@ -1,20 +1,17 @@
 import os
 
 DEV = os.environ.get('BENEATH_ENV') in ['dev', 'development']
-INTERNAL_NETWORK = bool(os.environ.get('BENEATH_INTERNAL_NETWORK'))
 
 BIGQUERY_PROJECT = "beneath"
 PYTHON_CLIENT_ID = "beneath-python"
 
-DEFAULT_WRITE_BATCH_SIZE = 10000
-DEFAULT_WRITE_BATCH_BYTES = 10000000
-DEFAULT_WRITE_DELAY_SECONDS = 1.0
 DEFAULT_READ_BATCH_SIZE = 1000
 DEFAULT_READ_ALL_MAX_BYTES = 10 * 2**20
-DEFAULT_SUBSCRIBE_PREFETCHED_RECORDS = 10000
-DEFAULT_SUBSCRIBE_CONCURRENT_CALLBACKS = 1000
-DEFAULT_SUBSCRIBE_POLL_AT_LEAST_EVERY_SECONDS = 60.0
-DEFAULT_SUBSCRIBE_POLL_AT_MOST_EVERY_SECONDS = 1.0
+DEFAULT_WRITE_DELAY_MS = 1000
+DEFAULT_WRITE_PIPELINE_STATE_DELAY_MS = 30000
+DEFAULT_SUBSCRIBE_POLL_AT_LEAST_EVERY_MS = 60000
+DEFAULT_SUBSCRIBE_POLL_AT_MOST_EVERY_MS = 1000
+MAX_WRITE_SIZE_BYTES = 10000000
 
 if DEV:
   BENEATH_FRONTEND_HOST = "http://localhost:3000"
